==> jc-1.4.0.tar.gz: gnu/xml/xpath/XPathParser__24yyException.h <==
// public class gnu.xml.xpath.XPathParser$yyException

// class file dependencies
// @dep_class 891f482b8882935 gnu_xml_xpath_XPathParser__24yyException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_gnu_xml_xpath_XPathParser__24yyException_H_
#define _JC_gnu_xml_xpath_XPathParser__24yyException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_XPathParser__24yyException$sub_refs	_jc_gnu_xml_xpath_XPathParser__24yyException$sub_refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24yyException$sub_nonrefs	_jc_gnu_xml_xpath_XPathParser__24yyException$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24yyException$refs	_jc_gnu_xml_xpath_XPathParser__24yyException$refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24yyException$nonrefs	_jc_gnu_xml_xpath_XPathParser__24yyException$nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24yyException$object	_jc_gnu_xml_xpath_XPathParser__24yyException$object;

typedef const struct _jc_gnu_xml_xpath_XPathParser__24yyException$vmethods	_jc_gnu_xml_xpath_XPathParser__24yyException$vmethods;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24yyException$vtable	_jc_gnu_xml_xpath_XPathParser__24yyException$vtable;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24yyException$vtype	_jc_gnu_xml_xpath_XPathParser__24yyException$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_XPathParser__24yyException$method$_init$c31b894660454d13(_jc_env *, struct _jc_gnu_xml_xpath_XPathParser__24yyException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_gnu_xml_xpath_XPathParser__24yyException$vmethods {
};

// Vtable
struct _jc_gnu_xml_xpath_XPathParser__24yyException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_gnu_xml_xpath_XPathParser__24yyException$vmethods	gnu_xml_xpath_XPathParser__24yyException;
};

// Vtype
struct _jc_gnu_xml_xpath_XPathParser__24yyException$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_XPathParser__24yyException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24yyException$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24yyException$refs {
    _jc_gnu_xml_xpath_XPathParser__24yyException$sub_refs	gnu_xml_xpath_XPathParser__24yyException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24yyException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24yyException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_gnu_xml_xpath_XPathParser__24yyException$sub_nonrefs	gnu_xml_xpath_XPathParser__24yyException;
};

// Object instance structure
struct _jc_gnu_xml_xpath_XPathParser__24yyException$object {
	_jc_gnu_xml_xpath_XPathParser__24yyException$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_XPathParser__24yyException$vtype	*vtype;
	_jc_gnu_xml_xpath_XPathParser__24yyException$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_XPathParser__24yyException$vtype _jc_gnu_xml_xpath_XPathParser__24yyException$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_XPathParser__24yyException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_XPathParser__24yyException$class_object;

#endif	/* _JC_gnu_xml_xpath_XPathParser__24yyException_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/xpath/XPathParser__24yyException.h <==
// public class gnu.xml.xpath.XPathParser$yyException

// class file dependencies
// @dep_class 891f482b8882935 gnu_xml_xpath_XPathParser__24yyException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_gnu_xml_xpath_XPathParser__24yyException_H_
#define _JC_gnu_xml_xpath_XPathParser__24yyException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_XPathParser__24yyException$sub_refs	_jc_gnu_xml_xpath_XPathParser__24yyException$sub_refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24yyException$sub_nonrefs	_jc_gnu_xml_xpath_XPathParser__24yyException$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24yyException$refs	_jc_gnu_xml_xpath_XPathParser__24yyException$refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24yyException$nonrefs	_jc_gnu_xml_xpath_XPathParser__24yyException$nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24yyException$object	_jc_gnu_xml_xpath_XPathParser__24yyException$object;

typedef const struct _jc_gnu_xml_xpath_XPathParser__24yyException$vmethods	_jc_gnu_xml_xpath_XPathParser__24yyException$vmethods;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24yyException$vtable	_jc_gnu_xml_xpath_XPathParser__24yyException$vtable;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24yyException$vtype	_jc_gnu_xml_xpath_XPathParser__24yyException$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_XPathParser__24yyException$method$_init$c31b894660454d13(_jc_env *, struct _jc_gnu_xml_xpath_XPathParser__24yyException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_xpath_XPathParser__24yyException$vmethods {
};

// Vtable
struct _jc_gnu_xml_xpath_XPathParser__24yyException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_gnu_xml_xpath_XPathParser__24yyException$vmethods	gnu_xml_xpath_XPathParser__24yyException;
};

// Vtype
struct _jc_gnu_xml_xpath_XPathParser__24yyException$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_XPathParser__24yyException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24yyException$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24yyException$refs {
    _jc_gnu_xml_xpath_XPathParser__24yyException$sub_refs	gnu_xml_xpath_XPathParser__24yyException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24yyException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24yyException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_gnu_xml_xpath_XPathParser__24yyException$sub_nonrefs	gnu_xml_xpath_XPathParser__24yyException;
};

// Object instance structure
struct _jc_gnu_xml_xpath_XPathParser__24yyException$object {
	_jc_gnu_xml_xpath_XPathParser__24yyException$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_XPathParser__24yyException$vtype	*vtype;
	_jc_gnu_xml_xpath_XPathParser__24yyException$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_XPathParser__24yyException$vtype _jc_gnu_xml_xpath_XPathParser__24yyException$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_XPathParser__24yyException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_XPathParser__24yyException$class_object;

#endif	/* _JC_gnu_xml_xpath_XPathParser__24yyException_H_ */
